@@ -6,6 +6,7 @@ import requests
 import pkgutil
 from loguru import logger
 import time
+from morpheuscypher import Cypher
 
 def _get_instance_ids_from_names(url,headers,names:list):
     session = FuturesSession()
@@ -19,14 +20,25 @@ def _get_instance_ids_from_names(url,headers,names:list):
             ids.append(i["id"])
     return(ids)
 
-def _tag_xaas_with_instance_ids(url,headers,target_id,instance_ids:list):
+def _get_aio_external_ips(url,headers,ids:list):
+    session = FuturesSession()
     endpoint = "/api/instances"
-    payload = {'instance':{'addTags':[{'name': 'Lab Instance IDs','value': instance_ids}]}}
-    try:
-        logger.info('Attempting to add tag to the instance')
-        resp = requests.put(f'{url}{endpoint}/{target_id}', headers=headers, verify=False, data=json.dumps(payload))
-        return(resp)
-    except Exception as e:
-        logger.error(f'Something went wrong inthe operation')
+    ips = []
+    futures=[session.get(f'{url}{endpoint}{i}',headers=headers,verify=False) for i in ids]
+    for future in as_completed(futures):
+        resp = future.result()   
+        if "200" in str(resp):
+            for node in resp["instance"]["containerDetails"]:
+                if "single-node" in node["externalHostname"]:
+                    ips.append(node["ip"])
+    return(ips)
 
+def _get_morpheus_license_from_cypher(url,token,cypher_name):
+    logger.info(f'Begin get_morpheus_license_from_cypher')
+    c = Cypher(url=url,token=token,ssl_verify=False)
+    out = c.get(cypher_name)
+    return(out)
 
+def sleep(time):
+    logger.info(f'Sleeping for {time}')
+    time.sleep(time)
\ No newline at end of file
